﻿using System.Collections.Generic;
using System.IO;
using System.Net;

namespace HttpServerSample
{
    public class Request
    {
        public string HttpMethod { get; private set; }
        public string HttpVersion { get; private set; }
        public string LocalUrl { get; private set; }
        public IPEndPoint IPEndPoint { get; set; }

        public Dictionary<string, string> Parameters { get; private set; }

        public Dictionary<string, string> Header { get; private set; }
 
        public Request(StreamReader reader)
        {
            var line = reader.ReadLine();
            var tokens = line.Split(' ');

            HttpMethod = tokens[0];
            LocalUrl = tokens[1];
            HttpVersion = tokens[2];

            Header = new Dictionary<string, string>();
            while((line = reader.ReadLine()) != null && line != "")
            {
                tokens = line.Split(':');
                Header.Add(tokens[0].Trim(), tokens[1].Trim());
            }

            Parameters = new Dictionary<string, string>();

            // Query String
            if(LocalUrl.IndexOf('?') != -1)
            {
                var parts = LocalUrl.Split(new char[] { '?' }, 2);
                LocalUrl = parts[0];

                createParameters(parts[1]);
            }

            // POST
            if (HttpMethod.Equals("POST"))
            {
                var length = int.Parse(Header["Content-Length"]);
                var content = new char[length];

                reader.Read(content, 0, length);

                createParameters(new string(content));
            }
        }

        public override string ToString()
        {
            var request = string.Format("{0} {1} {2}\r\n", HttpMethod, LocalUrl, HttpVersion);

            foreach (var entry in Header)
                request += string.Format("{0}: {1}\r\n", entry.Key, entry.Value);

            foreach (var param in Parameters)
                request += string.Format("{0} = {1}\r\n", param.Key, param.Value);

            return request + "\r\n";
        }

        private void createParameters(string queryString)
        {
            var parameters = queryString.Split('&');
            foreach (var parameter in parameters)
            {
                var keyValue = parameter.Split(new char[] { '=' }, 2);
                Parameters.Add(keyValue[0], keyValue[1]);
            }
        }
    }
}
