﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;

namespace HttpServerSample
{
    public class Response
    {
        public int StatusCode { get; private set; }
        public string Reason 
        { 
            get
            {
                return StatusCode > 0 ? statusCodes[StatusCode] : null;
            }
        }
        public string Content { get; private set; }


        private readonly Dictionary<int, string> statusCodes = new Dictionary<int, string>()
        {
            { 200, "OK" },
            { 401, "Unauthorized" },
            { 404, "Not found" },
            { 501, "Not implemented" }
        };

        private Request request;

        static public Response Create(Request request)
        {
            var response = new Response();
            response.request = request;

            if (request.HttpMethod.Equals("GET"))
                response.GET(request);
            else if (request.HttpMethod.Equals("POST"))
                response.POST(request);
            else 
                response.notImplemented();

            return response;
        }

        private void GET(Request request)
        {
            var file = request.LocalUrl.Trim('/');

            StatusCode = File.Exists(file) ? 200 : 404;
            Content = File.Exists(file) ? File.ReadAllText(file) : "";
        }

        private void POST(Request request)
        {
            GET(request);
        }

        private void notImplemented()
        {
            StatusCode = 501;
        }

        public override string ToString()
        {
            if (!authenticated())
                StatusCode = 401;

            var response = string.Format("HTTP/1.1 {0} {1}\r\n", StatusCode, Reason);

            response += "Connection: close\r\n";

            if (!authenticated())
                response += "WWW-Authenticate: Basic realm=SecArea\r\n\r\n";
            else
            {
                var filetype = Path.GetExtension(request.LocalUrl).TrimStart('.');
                if (filetype == "php")
                    filetype = "html";
                response += "Content-Type: text/" + filetype + ";charset=utf-8\r\n";
                response += "Set-Cookie: Computer=" + request.IPEndPoint.Address.ToString() + "\r\n";
                response += "\r\n";

                response += new Script(Content, request);
            }

            return response;
        }

        private bool authenticated()
        {
            if (!request.LocalUrl.Contains("secure"))
                return true;

            var authorization = request.Header.ContainsKey("Authorization") ? request.Header["Authorization"] : null;

            if (authorization == null)
                return false;

            var bytes = Convert.FromBase64String(authorization.Replace("Basic ", ""));
            var password = Encoding.UTF8.GetString(bytes);

            return password == "user:secure";
        }
    }
}
