﻿using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;

namespace HttpServerSample
{
    public class Script
    {
        public bool IsScriptFile { get; private set; }
        public bool IsPHP { get; private set; }

        private string content;
        private Request request;

        public Script(string content, Request request)
        {
            IsScriptFile = request.LocalUrl.Contains(".SSS.");
            IsPHP = request.LocalUrl.EndsWith(".php");
            this.content = content;
            this.request = request;
        }

        public override string ToString()
        {
            var generated = content;

            if (IsPHP)
                return generatePHP();

            if (!IsScriptFile)
                return content;

            // Parameter ersetzen
            foreach (var parameter in request.Parameters)
            {
                var key = "{{" + parameter.Key + "}}";
                generated = generated.Replace(key, parameter.Value);
            }

            // Cookie ersetzen
            if (request.Header.ContainsKey("Cookie"))
                generated = generated.Replace("{{Cookie}}", request.Header["Cookie"]);

            return generated;
        }

        private string generatePHP()
        {
            var php = new Process();

            php.StartInfo.FileName = "php.exe";
            php.StartInfo.Arguments = "-f " + request.LocalUrl.Substring(1);
            foreach (var item in request.Parameters)
            {
                php.StartInfo.Arguments += " " + item.Key + "=" + item.Value; 
            }
            php.StartInfo.UseShellExecute = false;
            php.StartInfo.RedirectStandardOutput = true;
            php.Start();

            var generated = php.StandardOutput.ReadToEnd();

            php.WaitForExit();

            return generated;
        }
    }
}
