﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using FlightSearch.Models;

namespace FlightSearch.Controllers
{
    public class FlightRouteController : Controller
    {
        private FlightContext db = new FlightContext();

        // GET: FlightRoute
        public ActionResult Index(string query)
        {

            var flights = from f
                          in db.FlightRoutes
                          select f;

            if (!string.IsNullOrEmpty(query))
            {
                flights = from f
                          in flights
                          where f.Date.ToString().Contains(query) ||
                                f.FlightNo.Contains(query) ||
                                f.FromAirport.Contains(query) ||
                                f.ToAirport.Contains(query)
                          select f;
            }
            return View(flights.ToList());

/*          Method Syntax 
            var flights = Queryable.AsQueryable(db.FlightRoutes);

            if (!string.IsNullOrEmpty(query))
            {
                flights = flights
                        .Where(f => f.Date.ToString().Contains(query) ||
                               f.FlightNo.Contains(query) ||
                               f.FromAirport.Contains(query) ||
                               f.ToAirport.Contains(query));
            }
            return View(flights.ToList());
 */
        }

        // GET: FlightRoute/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            FlightRoute flightRoute = db.FlightRoutes.Find(id);
            if (flightRoute == null)
            {
                return HttpNotFound();
            }
            return View(flightRoute);
        }

        // GET: FlightRoute/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: FlightRoute/Create
        // Aktivieren Sie zum Schutz vor übermäßigem Senden von Angriffen die spezifischen Eigenschaften, mit denen eine Bindung erfolgen soll. Weitere Informationen 
        // finden Sie unter http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,FlightNo,Date,From,To,FromAirport,ToAirport,Hints")] FlightRoute flightRoute)
        {
            if (ModelState.IsValid)
            {
                db.FlightRoutes.Add(flightRoute);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(flightRoute);
        }

        // GET: FlightRoute/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            FlightRoute flightRoute = db.FlightRoutes.Find(id);
            if (flightRoute == null)
            {
                return HttpNotFound();
            }
            return View(flightRoute);
        }

        // POST: FlightRoute/Edit/5
        // Aktivieren Sie zum Schutz vor übermäßigem Senden von Angriffen die spezifischen Eigenschaften, mit denen eine Bindung erfolgen soll. Weitere Informationen 
        // finden Sie unter http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,FlightNo,Date,From,To,FromAirport,ToAirport,Hints")] FlightRoute flightRoute)
        {
            if (ModelState.IsValid)
            {
                db.Entry(flightRoute).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(flightRoute);
        }

        // GET: FlightRoute/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            FlightRoute flightRoute = db.FlightRoutes.Find(id);
            if (flightRoute == null)
            {
                return HttpNotFound();
            }
            return View(flightRoute);
        }

        // POST: FlightRoute/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            FlightRoute flightRoute = db.FlightRoutes.Find(id);
            db.FlightRoutes.Remove(flightRoute);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
